@@ -2,9 +2,8 @@
  *
  *  OBEX Server
  *
- *  Copyright (C) 2007-2008  Nokia Corporation
- *  Copyright (C) 2007-2008  Instituto Nokia de Tecnologia (INdT)
- *  Copyright (C) 2007-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2007-2010  Nokia Corporation
+ *  Copyright (C) 2007-2010  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -27,6 +26,9 @@
 #include <config.h>
 #endif
 
-gint bluetooth_init(guint service, const gchar *name, const gchar *folder,
-			guint8 channel, gboolean auto_accept);
+gint bluetooth_init(guint service, const gchar *folder, gboolean secure,
+				gboolean auto_accept, gboolean symlinks,
+				const gchar *capability);
 void bluetooth_exit(void);
+void bluetooth_start(void);
+void bluetooth_stop(void);
